pub enum QueryMsg {
TokenInfo {},
TokenConfig {},
ContractStatus {},
ExchangeRate {},
Allowance {
owner: HumanAddr,
spender: HumanAddr,
key: String,
},
Balance {
address: HumanAddr,
key: String,
},
TransferHistory {
address: HumanAddr,
key: String,
page: Option<u32>,
page_size: u32,
},
TransactionHistory {
address: HumanAddr,
key: String,
page: Option<u32>,
page_size: u32,
},
Minters {},
}Expand description
SNIP20 queries
Variants
TokenInfo
TokenConfig
ContractStatus
ExchangeRate
Allowance
Balance
TransferHistory
TransactionHistory
Minters
Implementations
Sourceimpl QueryMsg
impl QueryMsg
Sourcepub fn query<Q: Querier, T: DeserializeOwned>(
&self,
querier: &Q,
block_size: usize,
callback_code_hash: String,
contract_addr: HumanAddr,
) -> StdResult<T>
pub fn query<Q: Querier, T: DeserializeOwned>( &self, querier: &Q, block_size: usize, callback_code_hash: String, contract_addr: HumanAddr, ) -> StdResult<T>
Returns a StdResult
Arguments
querier- a reference to the Querier dependency of the querying contractblock_size- pad the message to blocks of this sizecallback_code_hash- String holding the code hash of the contract being queriedcontract_addr- address of the contract being queried